package basics.datagraph;

import java.io.File;

import javatools.administrative.D;
import javatools.administrative.Parameters;

public class DataGraphManager {

  /**
   * initialises the  yago classes and relations given a path 
   * @param path
   * @return
   */
  public static boolean init(String path) {
    if (!new File(path).exists()) {
      D.pl("Path does not exist " + path);
      return false;
    }
    File classes = new File(path, "YagoClasses");
    boolean ok = YagoClasses.loadFrom(classes);
    if (!ok) {
      return false;
    }
    File relations = null;
    relations = new File(path, "Relations");
    return Relations.loadFrom(relations);
  }

  /**
   * initialises the yago relations and classes, should the path not be
   * specified then the classes are loaded from the jar file.
   */
  public static void init() {
    File classes = null;
    if (Parameters.isDefined("yagoDefinitionsFolder")) {
      classes = new File(Parameters.getFile("yagoDefinitionsFolder"), "YagoClasses");
      YagoClasses.loadFrom(classes);
    } else {
      //      Announce.
      YagoClasses.loadFromClass();
    }
    File relations = null;
    if (Parameters.isDefined("yagoDefinitionsFolder")) {
      relations = new File(Parameters.getFile("yagoDefinitionsFolder"), "Relations");
      Relations.loadFrom(relations);
    } else {
      Relations.loadFromClass();
    }
  }

  /**
   * for test
   * @param args
   * @throws Exception
   */
  public static void main(String[] args) throws Exception {
    try {
      Parameters.init(args == null || args.length == 0 ? "yago.ini" : args[0]);
      init();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
}
